# Generated by Django 3.1.2 on 2021-01-19 16:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0012_index_additions'),
        ('authentication', '0017_remove_fleetup_permission'),
        ('opcalendar', '0016_auto_20210119_1545'),
    ]

    operations = [
        migrations.AlterField(
            model_name='owner',
            name='character',
            field=models.ForeignKey(blank=True, default=None, help_text='Character used for syncing the calendar', null=True, on_delete=django.db.models.deletion.SET_DEFAULT, related_name='+', to='authentication.characterownership'),
        ),
        migrations.AlterField(
            model_name='owner',
            name='corporation',
            field=models.OneToOneField(blank=True, default=None, help_text='Corporation owning the calendar', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecorporationinfo'),
        ),
    ]
